littletable.DataObject

Module littletable :: Class DataObject |
[frames] | no frames]

# Class DataObject

source code

    object --+
             |
            DataObject

A generic semi-mutable object for storing data values in a table. Attributes can be set by passing in named arguments in the constructor, or by setting them as `object.attribute = value`. New attributes can be added any time, but updates are ignored. Table joins are returned as a Table of DataObjects.

Instance Methods
__init__(self, **kwargs) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__repr__(self) repr(x) | source code
__setattr__(self, attr, val) x.__setattr__('name', value) <==> x.name = value | source code
__getitem__(self, k) | source code
__eq__(self, other) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, **kwargs) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)

### __setattr__(self, attr, val) | source code
x.__setattr__('name', value) <==> x.name = value Overrides: object.__setattr__ (inherited documentation)